@@ -116,6 +116,8 @@ class NavigationStateMachine:
             # Удаляем state из kwargs если он есть (он больше не нужен)
             kwargs.pop("state", None)
 
+            previous_state = self.current_state
+
             # Выполняем выход из текущего состояния
             self._execute_exit_method(self._current_state)
 
@@ -127,7 +129,15 @@ class NavigationStateMachine:
             self._current_state = new_state
 
             # Выполняем вход в новое состояние и запускаем команду
-            self._execute_enter_method(self._current_state, *args, **kwargs)
+            try:
+                self._execute_enter_method(
+                    self._current_state, *args, **kwargs
+                )
+            except Exception as e:
+                self._logger.error(
+                    f"Ошибка при входе в состояние {new_state.name}, "
+                    f"откат к {previous_state.name}"
+                )
 
     def handle_command(
         self, command_instance: NavigationCommand, *args, **kwargs
